@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -359,7 +359,7 @@ SCIP_RETCODE runBenders(
       case BENDERS_STATUS_ADDEDCUT:
          break;
 
-      case BENDERS_STATUS_SUCESS:
+      case BENDERS_STATUS_SUCCESS:
          success = TRUE;
          primalbound = mastersolobj;
          break;
