@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -526,6 +526,10 @@ SCIP_RETCODE SCIPconcurrentSolve(
    idx = SCIPsyncstoreGetWinner(syncstore);
    assert(idx >= 0 && idx < nconcsolvers);
 
+   /* a paranoid safeguard for running in optimized mode */
+   if( idx < 0 || idx >= nconcsolvers )
+      idx = 0;
+
    SCIP_CALL( SCIPconcsolverGetSolvingData(concsolvers[idx], scip) );
 
    return retcode;
