@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -71,8 +71,7 @@
 #include "scip/scip_sol.h"
 #include "scip/scip_var.h"
 #include "scip/symmetry.h"
-#include <ctype.h>
-#include <string.h>
+
 
 /* constraint handler properties */
 #define CONSHDLR_NAME          "orbisack"
@@ -1891,19 +1890,18 @@ SCIP_DECL_CONSPARSE(consParseOrbisack)
    s = str;
 
    /* skip white space */
-   while ( *s != '\0' && isspace((unsigned char)*s) )
-      ++s;
+   SCIP_CALL( SCIPskipSpace((char**)&s) );
 
-   if ( strncmp(s, "partOrbisack(", 13) == 0 )
+   if( strncmp(s, "partOrbisack(", 13) == 0 )
    {
       ispporbisack = TRUE;
       isparttype = TRUE;
    }
-   else if ( strncmp(s, "packOrbisack(", 13) == 0 )
+   else if( strncmp(s, "packOrbisack(", 13) == 0 )
       ispporbisack = TRUE;
    else
    {
-      if ( strncmp(s, "fullOrbisack(", 13) != 0 )
+      if( strncmp(s, "fullOrbisack(", 13) != 0 )
       {
          SCIPerrorMessage("Syntax error - expected \"fullOrbisack(\", \"partOrbisack\" or \"packOrbisacj\": %s\n", s);
          *success = FALSE;
@@ -1918,58 +1916,63 @@ SCIP_DECL_CONSPARSE(consParseOrbisack)
 
    do
    {
-      /* skip whitespace */
-      while ( *s != '\0' && isspace((unsigned char)*s) )
-         ++s;
-
       /* parse variable name */
       SCIP_CALL( SCIPparseVarName(scip, s, &var, &endptr) );
-      if ( var == NULL )
+
+      if( var == NULL )
       {
-         SCIPerrorMessage("unknown variable name at '%s'\n", str);
-         *success = FALSE;
+         endptr = strchr(endptr, ')');
 
-         SCIPfreeBufferArray(scip, &vars2);
-         SCIPfreeBufferArray(scip, &vars1);
+         if( endptr == NULL || !firstcolumn )
+         {
+            SCIPerrorMessage("variable is missing.\n");
+            *success = FALSE;
+         }
 
-         return SCIP_OKAY;
+         break;
       }
 
-      if ( firstcolumn )
-         vars1[nrows] = var;
-      else
-         vars2[nrows] = var;
       s = endptr;
       assert( s != NULL );
 
-      firstcolumn = !firstcolumn;
+      /* skip white space */
+      SCIP_CALL( SCIPskipSpace((char**)&s) );
 
-      /* skip white space and ',' */
-      while ( *s != '\0' && ( isspace((unsigned char)*s) ||  *s == ',' ) )
-         ++s;
+      if( firstcolumn == ( *s == '.' || *s == ')' ) )
+      {
+         SCIPerrorMessage("there are not two variables per row.\n");
+         *success = FALSE;
+         break;
+      }
 
       /* begin new row if required */
-      if ( *s == '.' )
+      if( firstcolumn )
       {
          ++nrows;
-         ++s;
 
-         if ( nrows >= maxnrows )
+         if( nrows > maxnrows )
          {
-            int newsize;
-
-            newsize = SCIPcalcMemGrowSize(scip, nrows + 1);
-            SCIP_CALL( SCIPreallocBufferArray(scip, &vars1, newsize) );
-            SCIP_CALL( SCIPreallocBufferArray(scip, &vars2, newsize) );
-            maxnrows = newsize;
+            maxnrows = SCIPcalcMemGrowSize(scip, nrows);
+            SCIP_CALL( SCIPreallocBufferArray(scip, &vars1, maxnrows) );
+            SCIP_CALL( SCIPreallocBufferArray(scip, &vars2, maxnrows) );
+            assert( nrows <= maxnrows );
          }
-         assert( nrows < maxnrows );
-      }
-   }
-   while ( *s != ')' );
-   ++nrows;
 
-   SCIP_CALL( SCIPcreateConsBasicOrbisack(scip, cons, name, vars1, vars2, nrows, ispporbisack, isparttype, TRUE) );
+         vars1[nrows-1] = var;
+      }
+      else
+         vars2[nrows-1] = var;
+
+      firstcolumn = !firstcolumn;
+
+      /* skip ',' or '.' */
+      if( *s == ',' || *s == '.' )
+         ++s;
+   }
+   while( *s != ')' );
+
+   if( *success )
+      SCIP_CALL( SCIPcreateConsBasicOrbisack(scip, cons, name, vars1, vars2, nrows, ispporbisack, isparttype, TRUE) );
 
    SCIPfreeBufferArray(scip, &vars2);
    SCIPfreeBufferArray(scip, &vars1);
