@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -505,13 +505,13 @@ SCIP_RETCODE SCIPselectCutsHybrid(
 
       /* if the best cut of the remaining cuts is considered bad, we discard it and all remaining cuts */
       if( scores[0] < badscore )
-         goto TERMINATE;
+         break;
 
       ++(*nselectedcuts);
 
       /* if the maximal number of cuts was selected, we can stop here */
       if( *nselectedcuts == maxselectedcuts )
-         goto TERMINATE;
+         break;
 
       /* move the pointers to the next position and filter the remaining cuts to enforce the maximum parallelism constraint */
       ++cuts;
@@ -521,7 +521,6 @@ SCIP_RETCODE SCIPselectCutsHybrid(
       ncuts = filterWithParallelism(selectedcut, cuts, scores, ncuts, goodscore, goodmaxparall, maxparall);
    }
 
-TERMINATE:
    SCIPfreeBufferArray(scip, &scoresptr);
 
    return SCIP_OKAY;
