@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -105,7 +105,7 @@ SCIP_Real calcShiftVal(
    SCIP_Real lb;
    SCIP_Real ub;
    SCIP_Real obj;
-   SCIP_Real shiftval;
+   SCIP_Real newsolval;
 
    SCIP_COL* col;
    SCIP_ROW** colrows;
@@ -113,7 +113,6 @@ SCIP_Real calcShiftVal(
    SCIP_Bool shiftdown;
 
    int ncolrows;
-   int i;
 
    /* get variable's solution value, global bounds and objective coefficient */
    lb = SCIPvarGetLbGlobal(var);
@@ -122,18 +121,23 @@ SCIP_Real calcShiftVal(
    shiftdown = TRUE;
 
    /* determine shifting direction and maximal possible shifting w.r.t. corresponding bound */
-   if( obj > 0.0 && SCIPisFeasGE(scip, solval - 1.0, lb) )
-      shiftval = SCIPfeasFloor(scip, solval - lb);
-   else if( obj < 0.0 && SCIPisFeasLE(scip, solval + 1.0, ub) )
+   if( obj > 0.0 )
+      newsolval = SCIPfeasCeil(scip, lb);
+   else if( obj < 0.0 )
    {
-      shiftval = SCIPfeasFloor(scip, ub - solval);
+      newsolval = SCIPfeasFloor(scip, ub);
       shiftdown = FALSE;
    }
    else
+      newsolval = solval;
+
+   /* newsolval might be bounding solval -> avoid numerical shifting */
+   if( ( shiftdown && SCIPisFeasGE(scip, newsolval, solval) )
+      || ( !shiftdown && SCIPisFeasLE(scip, newsolval, solval) ) )
       return 0.0;
 
    SCIPdebugMsg(scip, "Try to shift %s variable <%s> with\n", shiftdown ? "down" : "up", SCIPvarGetName(var) );
-   SCIPdebugMsg(scip, "    lb:<%g> <= val:<%g> <= ub:<%g> and obj:<%g> by at most: <%g>\n", lb, solval, ub, obj, shiftval);
+   SCIPdebugMsg(scip, "    lb:<%g> <= val:<%g> <= ub:<%g> and obj:<%g> by at most: <%g>\n", lb, solval, ub, obj, newsolval - solval );
 
    /* get data of LP column */
    col = SCIPvarGetCol(var);
@@ -143,49 +147,63 @@ SCIP_Real calcShiftVal(
 
    assert(ncolrows == 0 || (colrows != NULL && colvals != NULL));
 
-   /* find minimal shift value, st. all rows stay valid */
-   for( i = 0; i < ncolrows && shiftval > 0.0; ++i )
+   /* find maximal shift value, st. all rows stay valid */
+   for( int i = 0; i < ncolrows; ++i )
    {
       SCIP_ROW* row;
       int rowpos;
 
       row = colrows[i];
       rowpos = SCIProwGetLPPos(row);
-      assert(-1 <= rowpos && rowpos < SCIPgetNLPRows(scip) );
+      assert( -1 <= rowpos && rowpos < SCIPgetNLPRows(scip) );
 
       /* only global rows need to be valid */
       if( rowpos >= 0 && !SCIProwIsLocal(row) )
       {
-         SCIP_Real shiftvalrow;
+         SCIP_Real side;
+         SCIP_Bool left;
 
-         assert(SCIProwIsInLP(row));
+         left = shiftdown == ( colvals[i] > 0 );
+         side = left ? SCIProwGetLhs(row) : SCIProwGetRhs(row);
 
-         if( shiftdown == (colvals[i] > 0) )
-            shiftvalrow = SCIPfeasFloor(scip, (activities[rowpos] - SCIProwGetLhs(row)) / ABS(colvals[i]));
-         else
-            shiftvalrow = SCIPfeasFloor(scip, (SCIProwGetRhs(row) -  activities[rowpos]) / ABS(colvals[i]));
-#ifdef SCIP_DEBUG
-         if( shiftvalrow < shiftval )
+         /* only finite bounds need to be considered */
+         if( !SCIPisInfinity(scip, left ? -side : side) )
          {
-            SCIPdebugMsg(scip, " -> The shift value had to be reduced to <%g>, because of row <%s>.\n",
-               shiftvalrow, SCIProwGetName(row));
-            SCIPdebugMsg(scip, "    lhs:<%g> <= act:<%g> <= rhs:<%g>, colval:<%g>\n",
-               SCIProwGetLhs(row), activities[rowpos], SCIProwGetRhs(row), colvals[i]);
+            SCIP_Real newsolvalrow;
+
+            assert( SCIProwIsInLP(row) );
+            newsolvalrow = solval + (side - activities[rowpos]) / colvals[i];
+
+            /* update shifting value */
+            if( ( shiftdown && newsolvalrow > newsolval ) || ( !shiftdown && newsolvalrow < newsolval ) )
+            {
+               SCIP_Real activity;
+
+               activity = activities[rowpos] + colvals[i] * ((shiftdown ? floor(newsolvalrow) : ceil(newsolvalrow)) - solval);
+
+               /* ensure that shifting preserves feasibility */
+               if( shiftdown == ( ( left && SCIPisFeasGE(scip, activity, side) )
+                                 || ( !left && SCIPisFeasLE(scip, activity, side) ) ) )
+                  newsolval = floor(newsolvalrow);
+               else
+                  newsolval = ceil(newsolvalrow);
+
+               SCIPdebugMsg(scip, " -> The shift value has to be set to <%g>, because of row <%s>.\n",
+                  newsolval - solval, SCIProwGetName(row));
+               SCIPdebugMsg(scip, "    lhs:<%g> <= act:<%g> <= rhs:<%g>, colval:<%g>\n",
+                  SCIProwGetLhs(row), activities[rowpos], SCIProwGetRhs(row), colvals[i]);
+
+               /* newsolval might have reached solval -> avoid numerical shifting */
+               if( ( shiftdown && SCIPisFeasGE(scip, newsolval, solval) )
+                  || ( !shiftdown && SCIPisFeasLE(scip, newsolval, solval) ) )
+                  return 0.0;
+            }
          }
-#endif
-         shiftval = MIN(shiftval, shiftvalrow);
-         /* shiftvalrow might be negative, if we detected infeasibility -> make sure that shiftval is >= 0 */
-         shiftval = MAX(shiftval, 0.0);
       }
    }
-   if( shiftdown )
-      shiftval *= -1.0;
 
    /* we must not shift variables to infinity */
-   if( SCIPisInfinity(scip, solval + shiftval) )
-      shiftval = 0.0;
-
-   return shiftval;
+   return SCIPisInfinity(scip, shiftdown ? -newsolval : newsolval) ? 0.0 : newsolval - solval;
 }
 
 
@@ -203,7 +221,6 @@ SCIP_RETCODE updateRowActivities(
    SCIP_COL* col;
 
    int ncolrows;
-   int i;
 
    assert(activities != NULL);
 
@@ -215,7 +232,7 @@ SCIP_RETCODE updateRowActivities(
    assert(ncolrows == 0 || (colrows != NULL && colvals != NULL));
 
    /* enumerate all rows with nonzero entry in this column */
-   for( i = 0; i < ncolrows; ++i )
+   for( int i = 0; i < ncolrows; ++i )
    {
       SCIP_ROW* row;
       int rowpos;
@@ -255,7 +272,6 @@ SCIP_RETCODE setupAndSolveSubscipOneopt(
    SCIP_HASHMAP* varmapfw;                   /* mapping of SCIP variables to sub-SCIP variables */
    SCIP_SOL* startsol;
    int nvars;                                /* number of original problem's variables          */
-   int i;
 
    assert(scip != NULL);
    assert(subscip != NULL);
@@ -273,7 +289,7 @@ SCIP_RETCODE setupAndSolveSubscipOneopt(
 
    /* get variable image and create start solution for the subproblem  */
    SCIP_CALL( SCIPcreateOrigSol(subscip, &startsol, NULL) );
-   for( i = 0; i < nvars; i++ )
+   for( int i = 0; i < nvars; ++i )
    {
       subvars[i] = (SCIP_VAR*) SCIPhashmapGetImage(varmapfw, vars[i]);
       if( subvars[i] != NULL )
@@ -468,14 +484,12 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
 
    SCIP_Real lb;
    SCIP_Real ub;
-   SCIP_Bool localrows;
    SCIP_Bool valid;
    int nchgbound;
    int nbinvars;
    int nintvars;
    int nvars;
    int nlprows;
-   int i;
    int nshiftcands;
    int shiftcandssize;
    int nsuccessfulshifts;
@@ -582,7 +596,7 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
 
    nchgbound = 0;
    /* change solution values due to possible global bound changes first */
-   for( i = nvars - 1; i >= 0; --i )
+   for( int i = nvars - 1; i >= 0; --i )
    {
       SCIP_VAR* var;
       SCIP_Real solval;
@@ -615,11 +629,10 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
    SCIP_CALL( SCIPgetLPRowsData(scip, &lprows, &nlprows) );
    SCIP_CALL( SCIPallocBufferArray(scip, &activities, nlprows) );
 
-   localrows = FALSE;
    valid = TRUE;
 
    /* initialize LP row activities */
-   for( i = 0; i < nlprows; ++i )
+   for( int i = 0; i < nlprows; ++i )
    {
       SCIP_ROW* row;
 
@@ -638,8 +651,6 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
             break;
          }
       }
-      else
-         localrows = TRUE;
    }
 
    if( !valid )
@@ -671,7 +682,7 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
       /* @todo if useloop=TRUE store for each variable which constraint blocked it and only iterate over those variables
        *       in the following rounds for which the constraint slack was increased by previous shifts
        */
-      for( i = 0; i < nintvars; i++ )
+      for( int i = 0; i < nintvars; ++i )
       {
          if( SCIPvarGetStatus(vars[i]) == SCIP_VARSTATUS_COLUMN )
          {
@@ -732,12 +743,12 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
             /* sort the variables by their objective, optionally weighted with the shiftval */
             if( heurdata->weightedobj )
             {
-               for( i = 0; i < nshiftcands; ++i )
+               for( int i = 0; i < nshiftcands; ++i )
                   objcoeffs[i] = SCIPvarGetObj(shiftcands[i])*shiftvals[i];
             }
             else
             {
-               for( i = 0; i < nshiftcands; ++i )
+               for( int i = 0; i < nshiftcands; ++i )
                   objcoeffs[i] = SCIPvarGetObj(shiftcands[i]);
             }
 
@@ -745,7 +756,7 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
             SCIPsortRealPtr(objcoeffs, (void**)shiftcands, nshiftcands);
 
             /* try to shift each variable -> Activities have to be updated */
-            for( i = 0; i < nshiftcands; ++i )
+            for( int i = 0; i < nshiftcands; ++i )
             {
                var = shiftcands[i];
                assert(var != NULL);
@@ -780,10 +791,10 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
       {
          SCIP_Bool success;
 
-         /* since we ignore local rows, we cannot guarantee their feasibility and have to set the checklprows flag to
-          * TRUE if local rows are present
+         /* since activities are maintained iteratively, we cannot guarantee the feasibility of the shiftings and have
+          * to set the checklprows flag to TRUE
           */
-         SCIP_CALL( SCIPtrySol(scip, worksol, FALSE, FALSE, FALSE, FALSE, localrows, &success) );
+         SCIP_CALL( SCIPtrySol(scip, worksol, FALSE, FALSE, FALSE, FALSE, TRUE, &success) );
 
          if( success )
          {
@@ -805,7 +816,7 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
          SCIP_CALL( SCIPstartDive(scip) );
 
          /* set the bounds of the variables: fixed for integers, global bounds for continuous */
-         for( i = 0; i < nvars; ++i )
+         for( int i = 0; i < nvars; ++i )
          {
             if( SCIPvarGetStatus(vars[i]) == SCIP_VARSTATUS_COLUMN )
             {
@@ -814,7 +825,7 @@ SCIP_DECL_HEUREXEC(heurExecOneopt)
             }
          }
          /* apply this after global bounds to not cause an error with intermediate empty domains */
-         for( i = 0; i < nintvars; ++i )
+         for( int i = 0; i < nintvars; ++i )
          {
             if( SCIPvarGetStatus(vars[i]) == SCIP_VARSTATUS_COLUMN )
             {
