@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -1698,6 +1698,8 @@ SCIP_DECL_NLHDLRENFO(nlhdlrEnfoPerspective)
          * therefore we are now happy
          */
          assert(!doprobingind);
+         SCIPfreeBufferArrayNull(scip, &probingvars);
+         SCIPfreeBufferArrayNull(scip, &probingdoms);
          goto TERMINATE;
       }
 
@@ -1730,14 +1732,15 @@ SCIP_DECL_NLHDLRENFO(nlhdlrEnfoPerspective)
          SCIPfreeBufferArray(scip, &solvals);
 #endif
 
+         SCIPfreeBufferArrayNull(scip, &probingvars);
+         SCIPfreeBufferArrayNull(scip, &probingdoms);
+
          if( propagate )
          { /* we are in the root node and startProbing did propagation */
             /* probing propagation might have detected infeasibility */
             if( cutoff_probing )
             {
                /* indicator == 1 is infeasible -> set indicator to 0 */
-               SCIPfreeBufferArrayNull(scip, &probingvars);
-               SCIPfreeBufferArrayNull(scip, &probingdoms);
 
                SCIP_CALL( SCIPendProbing(scip) );
 
@@ -1816,14 +1819,14 @@ SCIP_DECL_NLHDLRENFO(nlhdlrEnfoPerspective)
             SCIP_CALL( SCIPnlhdlrEstimate(scip, conshdlr, nlhdlr2, expr,
                   nlhdlr2exprdata, soladj,
                   nlhdlr2auxvalue, overestimate, SCIPgetSolVal(scip, solcopy, auxvar),
-                  addbranchscores, rowpreps2, &success2, &addedbranchscores2j) );
+                  FALSE, rowpreps2, &success2, &addedbranchscores2j) );
          }
          else
          {
             SCIP_CALL( SCIPnlhdlrEstimate(scip, conshdlr, nlhdlr2, expr,
                   nlhdlr2exprdata, solcopy,
                   nlhdlr2auxvalue, overestimate, SCIPgetSolVal(scip, solcopy, auxvar),
-                  addbranchscores, rowpreps2, &success2, &addedbranchscores2j) );
+                  FALSE, rowpreps2, &success2, &addedbranchscores2j) );
          }
 
          minidx = SCIPgetPtrarrayMinIdx(scip, rowpreps2);
@@ -1932,7 +1935,7 @@ SCIP_DECL_NLHDLRENFO(nlhdlrEnfoPerspective)
          (void) strcat(SCIProwprepGetName(rowprep), SCIPvarGetName(indicator));
 
          SCIP_CALL( SCIPprocessRowprepNonlinear(scip, nlhdlr, cons, expr, rowprep, overestimate, auxvar, auxvalue,
-               allowweakcuts, SCIPgetBoolarrayVal(scip, addedbranchscores2, r), addbranchscores, solcopy, &resultr) );
+               allowweakcuts, SCIPgetBoolarrayVal(scip, addedbranchscores2, r), FALSE, solcopy, &resultr) );
 
          if( resultr == SCIP_SEPARATED )
             *result = SCIP_SEPARATED;
@@ -1960,8 +1963,6 @@ SCIP_DECL_NLHDLRENFO(nlhdlrEnfoPerspective)
          SCIPfreeRowprep(scip, &rowprep);
       }
 
-      SCIPfreeBufferArrayNull(scip, &probingvars);
-      SCIPfreeBufferArrayNull(scip, &probingdoms);
       SCIP_CALL( SCIPclearPtrarray(scip, rowpreps) );
    }
 
