@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -34,7 +34,6 @@
 /*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/
 
 #include "blockmemshell/memory.h"
-#include <ctype.h>
 #include "scip/cons_linear.h"
 #include "scip/pub_fileio.h"
 #include "scip/pub_message.h"
@@ -50,12 +49,11 @@
 #include "scip/scip_prob.h"
 #include "scip/scip_reader.h"
 #include "scip/scip_var.h"
-#include <string.h>
-
 #if !defined(_WIN32) && !defined(_WIN64)
 #include <strings.h> /*lint --e{766}*/ /* needed for strncasecmp() */
 #endif
 
+
 #define READER_NAME             "cipreader"
 #define READER_DESC             "file reader for CIP (Constraint Integer Program) format"
 #define READER_EXTENSION        "cip"
@@ -260,8 +258,7 @@ SCIP_RETCODE getStatistics(
          *s = '\0';
 
       /* remove white space (tabs, ' ') in front of the name */
-      while( isspace((unsigned char)* name) )
-         ++name;
+      SCIP_CALL( SCIPskipSpace(&name) );
 
       /* set problem name */
       SCIP_CALL( SCIPsetProbName(scip, name) );
@@ -304,8 +301,7 @@ SCIP_RETCODE getObjective(
    SCIPdebugMsg(scip, "parse objective information\n");
 
    /* remove white space */
-   while ( isspace((unsigned char)* buf) )
-      ++buf;
+   SCIP_CALL( SCIPskipSpace(&buf) );
 
    if( strncasecmp(buf, "Sense", 5) == 0 )
    {
@@ -323,8 +319,7 @@ SCIP_RETCODE getObjective(
       ++name;
 
       /* remove white space in front of the name */
-      while( isspace((unsigned char)* name) )
-         ++name;
+      SCIP_CALL( SCIPskipSpace(&name) );
 
       if( strncasecmp(name, "minimize", 3) == 0 )
          objsense = SCIP_OBJSENSE_MINIMIZE;
@@ -357,8 +352,7 @@ SCIP_RETCODE getObjective(
       ++name;
 
       /* remove white space in front of the name */
-      while(isspace((unsigned char)*name))
-         ++name;
+      SCIP_CALL( SCIPskipSpace(&name) );
 
       if ( SCIPstrToRealValue(name, &off, &endptr) )
       {
@@ -388,8 +382,7 @@ SCIP_RETCODE getObjective(
       ++name;
 
       /* remove white space in front of the name */
-      while(isspace((unsigned char)*name))
-         ++name;
+      SCIP_CALL( SCIPskipSpace(&name) );
 
       if ( SCIPstrToRealValue(name, &scale, &endptr) )
       {
@@ -524,6 +517,7 @@ SCIP_RETCODE getFixedVariable(
          cipinput->haserror = TRUE;
          return SCIP_OKAY;
       }
+
       assert(SCIPvarIsBinary(var));
       assert(SCIPvarIsBinary(negvar));
 
@@ -570,8 +564,7 @@ SCIP_RETCODE getFixedVariable(
 
       /* check whether constant is 0.0 */
       str = endptr;
-      while ( *str != '\0' && isspace(*str) )
-         ++str;
+      SCIP_CALL( SCIPskipSpace((char**)&str) );
       /* if next char is '<' we found a variable -> constant is 0 */
       if ( *str != '<' )
       {
