@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -42,7 +42,6 @@
 
 /*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/
 
-#include <ctype.h>
 #include "scip/debug.h"
 #include "scip/pub_message.h"
 #include "scip/pub_misc.h"
@@ -52,7 +51,6 @@
 #include "scip/struct_scip.h"
 #include "scip/scip_lp.h"
 #include "scip/scip_message.h"
-#include <string.h>
 
 
 /* In debug mode, the following methods are implemented as function calls to ensure
@@ -420,8 +418,8 @@ SCIP_Bool SCIPparseReal(
    localstr = (char*)str;
 
    /* ignore white space */
-   while(isspace((unsigned char)*localstr))
-      ++localstr;
+   if( SCIPskipSpace(&localstr) != SCIP_OKAY )
+      return FALSE;
 
    /* test for a special infinity first */
    if( strncmp(localstr, "+infinity", 9) == 0 )
@@ -439,7 +437,7 @@ SCIP_Bool SCIPparseReal(
    else
    {
       /* parse a finite value */
-      return SCIPstrToRealValue(str, value, endptr);
+      return SCIPstrToRealValue(localstr, value, endptr);
    }
 }
 
@@ -1310,8 +1308,8 @@ SCIP_Longint SCIPconvertRealToLongint(
 {
    assert(SCIPisFeasIntegral(scip, real));
    assert(SCIPisFeasEQ(scip, real, (SCIP_Real)(SCIP_Longint)(real < 0 ? real - 0.5 : real + 0.5)));
-   assert(real < SCIP_LONGINT_MAX);
-   assert(real > SCIP_LONGINT_MIN);
+   assert(real < (SCIP_Real)SCIP_LONGINT_MAX);
+   assert(real > (SCIP_Real)SCIP_LONGINT_MIN);
 
    return (SCIP_Longint)(real < 0 ? (real - 0.5) : (real + 0.5));
 }
