@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -529,7 +529,7 @@ Test(checkad, griewank)
 static SCIP_EXPR* vexprs[DIM];
 static SCIP_Real vvals[DIM];
 static SCIP_Real grad[DIM];
-static SCIP_CLOCK* clock;
+static SCIP_CLOCK* cpuclock;
 
 static
 void performance_setup(void)
@@ -549,7 +549,7 @@ void performance_setup(void)
       SCIP_CALL_ABORT( SCIPcreateExprVaridx(scip, &vexprs[i], i, NULL, NULL) );
    }
 
-   SCIP_CALL_ABORT( SCIPcreateCPUClock(scip, &clock) );
+   SCIP_CALL_ABORT( SCIPcreateCPUClock(scip, &cpuclock) );
 }
 
 static
@@ -557,7 +557,7 @@ void performance_teardown(void)
 {
    int i;
 
-   SCIP_CALL_ABORT( SCIPfreeClock(scip, &clock) );
+   SCIP_CALL_ABORT( SCIPfreeClock(scip, &cpuclock) );
 
    for( i = DIM-1; i >= 0; --i )
    {
@@ -641,43 +641,43 @@ Test(performance, quad)
             printf("\n");
           } */
 
-         SCIPresetClock(scip, clock);
-         SCIPstartClock(scip, clock);
+         SCIPresetClock(scip, cpuclock);
+         SCIPstartClock(scip, cpuclock);
          SCIP_CALL( SCIPexprintCompile(scip, exprint, expr, &exprintdata) );
-         SCIPstopClock(scip, clock);
-         compiletime += SCIPgetClockTime(scip, clock);
+         SCIPstopClock(scip, cpuclock);
+         compiletime += SCIPgetClockTime(scip, cpuclock);
 
          if( SCIPexprintGetExprCapability(scip, exprint, expr, exprintdata) & SCIP_EXPRINTCAPABILITY_FUNCVALUE )
          {
-            SCIPresetClock(scip, clock);
-            SCIPstartClock(scip, clock);
+            SCIPresetClock(scip, cpuclock);
+            SCIPstartClock(scip, cpuclock);
             SCIP_CALL( SCIPexprintEval(scip, exprint, expr, exprintdata, vvals, &val) );
-            SCIPstopClock(scip, clock);
-            evaltime += SCIPgetClockTime(scip, clock);
+            SCIPstopClock(scip, cpuclock);
+            evaltime += SCIPgetClockTime(scip, cpuclock);
          }
 
          if( SCIPexprintGetExprCapability(scip, exprint, expr, exprintdata) & SCIP_EXPRINTCAPABILITY_GRADIENT )
          {
-            SCIPresetClock(scip, clock);
-            SCIPstartClock(scip, clock);
+            SCIPresetClock(scip, cpuclock);
+            SCIPstartClock(scip, cpuclock);
             SCIP_CALL( SCIPexprintGrad(scip, exprint, expr, exprintdata, vvals, FALSE, &val, grad) );
-            SCIPstopClock(scip, clock);
-            gradtime += SCIPgetClockTime(scip, clock);
+            SCIPstopClock(scip, cpuclock);
+            gradtime += SCIPgetClockTime(scip, cpuclock);
          }
 
          if( SCIPexprintGetExprCapability(scip, exprint, expr, exprintdata) & SCIP_EXPRINTCAPABILITY_HESSIAN )
          {
-            SCIPresetClock(scip, clock);
-            SCIPstartClock(scip, clock);
+            SCIPresetClock(scip, cpuclock);
+            SCIPstartClock(scip, cpuclock);
             SCIP_CALL( SCIPexprintHessianSparsity(scip, exprint, expr, exprintdata, vvals, &rowidxs, &colidxs, &nnz) );
-            SCIPstopClock(scip, clock);
-            hessiansparsitytime += SCIPgetClockTime(scip, clock);
+            SCIPstopClock(scip, cpuclock);
+            hessiansparsitytime += SCIPgetClockTime(scip, cpuclock);
 
-            SCIPresetClock(scip, clock);
-            SCIPstartClock(scip, clock);
+            SCIPresetClock(scip, cpuclock);
+            SCIPstartClock(scip, cpuclock);
             SCIP_CALL( SCIPexprintHessian(scip, exprint, expr, exprintdata, vvals, FALSE, &val, &rowidxs, &colidxs, &hessianvals, &nnz) );
-            SCIPstopClock(scip, clock);
-            hessiantime += SCIPgetClockTime(scip, clock);
+            SCIPstopClock(scip, cpuclock);
+            hessiantime += SCIPgetClockTime(scip, cpuclock);
 
             /* check that Hessian is correct */
             for( i = 0; i < nnz; ++i )
@@ -752,43 +752,43 @@ Test(performance, griewank)
          SCIP_Real* hessianvals;
          int nnz;
 
-         SCIPresetClock(scip, clock);
-         SCIPstartClock(scip, clock);
+         SCIPresetClock(scip, cpuclock);
+         SCIPstartClock(scip, cpuclock);
          SCIP_CALL( SCIPexprintCompile(scip, exprint, exprsum, &exprintdata) );
-         SCIPstopClock(scip, clock);
-         compiletime += SCIPgetClockTime(scip, clock);
+         SCIPstopClock(scip, cpuclock);
+         compiletime += SCIPgetClockTime(scip, cpuclock);
 
          if( SCIPexprintGetExprCapability(scip, exprint, exprsum, exprintdata) & SCIP_EXPRINTCAPABILITY_FUNCVALUE )
          {
-            SCIPresetClock(scip, clock);
-            SCIPstartClock(scip, clock);
+            SCIPresetClock(scip, cpuclock);
+            SCIPstartClock(scip, cpuclock);
             SCIP_CALL( SCIPexprintEval(scip, exprint, exprsum, exprintdata, vvals, &val) );
-            SCIPstopClock(scip, clock);
-            evaltime += SCIPgetClockTime(scip, clock);
+            SCIPstopClock(scip, cpuclock);
+            evaltime += SCIPgetClockTime(scip, cpuclock);
          }
 
          if( SCIPexprintGetExprCapability(scip, exprint, exprsum, exprintdata) & SCIP_EXPRINTCAPABILITY_GRADIENT )
          {
-            SCIPresetClock(scip, clock);
-            SCIPstartClock(scip, clock);
+            SCIPresetClock(scip, cpuclock);
+            SCIPstartClock(scip, cpuclock);
             SCIP_CALL( SCIPexprintGrad(scip, exprint, exprsum, exprintdata, vvals, FALSE, &val, grad) );
-            SCIPstopClock(scip, clock);
-            gradtime += SCIPgetClockTime(scip, clock);
+            SCIPstopClock(scip, cpuclock);
+            gradtime += SCIPgetClockTime(scip, cpuclock);
          }
 
          if( SCIPexprintGetExprCapability(scip, exprint, exprsum, exprintdata) & SCIP_EXPRINTCAPABILITY_HESSIAN )
          {
-            SCIPresetClock(scip, clock);
-            SCIPstartClock(scip, clock);
+            SCIPresetClock(scip, cpuclock);
+            SCIPstartClock(scip, cpuclock);
             SCIP_CALL( SCIPexprintHessianSparsity(scip, exprint, exprsum, exprintdata, vvals, &rowidxs, &colidxs, &nnz) );
-            SCIPstopClock(scip, clock);
-            hessiansparsitytime += SCIPgetClockTime(scip, clock);
+            SCIPstopClock(scip, cpuclock);
+            hessiansparsitytime += SCIPgetClockTime(scip, cpuclock);
 
-            SCIPresetClock(scip, clock);
-            SCIPstartClock(scip, clock);
+            SCIPresetClock(scip, cpuclock);
+            SCIPstartClock(scip, cpuclock);
             SCIP_CALL( SCIPexprintHessian(scip, exprint, exprsum, exprintdata, vvals, FALSE, &val, &rowidxs, &colidxs, &hessianvals, &nnz) );
-            SCIPstopClock(scip, clock);
-            hessiantime += SCIPgetClockTime(scip, clock);
+            SCIPstopClock(scip, cpuclock);
+            hessiantime += SCIPgetClockTime(scip, cpuclock);
          }
 
          SCIP_CALL( SCIPexprintFreeData(scip, exprint, exprsum, &exprintdata) );
@@ -820,8 +820,8 @@ Test(performance, signpower)
       SCIP_CALL( SCIPreleaseExpr(scip, &term) );
    }
 
-   SCIPresetClock(scip, clock);
-   SCIPstartClock(scip, clock);
+   SCIPresetClock(scip, cpuclock);
+   SCIPstartClock(scip, cpuclock);
 
    SCIP_CALL( SCIPexprintCompile(scip, exprint, expr, &exprintdata) );
 
@@ -838,7 +838,7 @@ Test(performance, signpower)
       SCIP_CALL( SCIPexprintHessian(scip, exprint, expr, exprintdata, vvals, FALSE, &val, &rowidxs, &colidxs, &hessianvals, &nnz) );
    }
 
-   printf("time: %g\n", SCIPgetClockTime(scip, clock));
+   printf("time: %g\n", SCIPgetClockTime(scip, cpuclock));
 
 TERMINATE:
    SCIP_CALL( SCIPexprintFreeData(scip, exprint, expr, &exprintdata) );
@@ -866,8 +866,8 @@ Test(performance, intpower)
       SCIP_CALL( SCIPreleaseExpr(scip, &term) );
    }
 
-   SCIPresetClock(scip, clock);
-   SCIPstartClock(scip, clock);
+   SCIPresetClock(scip, cpuclock);
+   SCIPstartClock(scip, cpuclock);
 
    SCIP_CALL( SCIPexprintCompile(scip, exprint, expr, &exprintdata) );
 
@@ -884,7 +884,7 @@ Test(performance, intpower)
       SCIP_CALL( SCIPexprintHessian(scip, exprint, expr, exprintdata, vvals, FALSE, &val, &rowidxs, &colidxs, &hessianvals, &nnz) );
    }
 
-   printf("time: %g\n", SCIPgetClockTime(scip, clock));
+   printf("time: %g\n", SCIPgetClockTime(scip, cpuclock));
 
 TERMINATE:
    SCIP_CALL( SCIPexprintFreeData(scip, exprint, expr, &exprintdata) );
